'' =================================================================================================
''
''   File....... jm_rn-42_terminal.spin
''   Purpose.... Connect to RN-42 Bluetooth adapter via PST 
''   Author..... Jon "JonnyMac" McPhalen
''               Copyright (c) 2015 Jon McPhalen
''               -- see below for terms of use
''   E-mail..... jon@jonmcphalen.com
''   Started.... 
''   Updated.... 26 JAN 2015 
''
'' =================================================================================================

{

  Connections:

    Set RN-42 power jumper to 3.3V

    P15 <-- RN-42.TX
    P14 --> RN-42.TX

    Connect RN-42.RTS to RN-42.CTS

    Connect RN-42 to 3.3V and GND rails

}


con { timing }

  _clkmode = xtal1 + pll16x
  _xinfreq = 5_000_000                                           ' use 5MHz crystal

  CLK_FREQ = _xinfreq * (_clkmode >> 6)                          ' system freq as a constant
  MS_001   = CLK_FREQ / 1_000                                    ' ticks in 1ms
  US_001   = CLK_FREQ / 1_000_000                                ' ticks in 1us
                                                                  
                                                                  
con { activity board io pins }                                    
                                                                  
  RX1     = 31                                                   ' programming / terminal
  TX1     = 30                                                    
                                                                  
  SDA     = 29                                                   ' eeprom / i2c
  SCL     = 28                                                    
                                                                  
  AUD_RT  = 27                                                   ' audio (d/a) outputs
  AUD_LF  = 26                                                    
                                                                  
  LED_1   = 27                                                   ' leds (on audio outputs)
  LED_L   = 26                                                    
                                                                  
  SD_CS   = 25                                                   ' usd card
  SD_DI   = 24                                                    
  SD_CLK  = 23                                                    
  SD_DO   = 22                                                    
                                                                  
  ADC_CS  = 21                                                   ' adc input
  ADC_CLK = 20                                                    
  ADC_DO  = 19 { miso }                                           
  ADC_DI  = 18 { mosi }                                           
                                                                  
  SVO_6   = 17                                                   ' servo headers
  SVO_5   = 16                                                    
                                                                  
  SVO_4   = 15                                                    
  SVO_3   = 14                                                    
                                                                  
  SVO_2   = 13                                                    
  SVO_1   = 12                                                    

  
  RX2     = 15                                                   ' to rn-42 tx pin (3.3v mode)
  TX2     = 14                                                   ' to rn-42 rx pin


con 

  #(-1), IS_ON, IS_OFF


obj

  term  : "jm_fullduplexserial"                                  ' * serial for terminal
  btcom : "jm_fullduplexserial"                                  ' * serial for rn-42  
  io    : "jm_io"                                                '   basic io
  time  : "jm_time"                                              '   delays/timing 
                                                                  
' * uses cog when loaded                                          
                                                                  
                                                                  
var                                                               
                                                                  
                                                                  
pub main | ch                                                    
                                                                  
  setup

  term.tx(term#CLS)
  term.str(string("RN-42 Terminal", 13, 13))

  term.rxflush                                                   ' clear any start-up trash
  btcom.rxflush                                                       
                                                                  
  repeat
    ch := term.rxcheck
    if (ch => 0)
      btcom.tx(ch)

    ch := btcom.rxcheck
    if (ch => 0)
      term.tx(ch)                                                              
                                                                  
                                                                  
pub setup                                                         
                                                                  
  term.start(RX1, TX1, %0000, 115_200)                           ' start serial for terminal

  btcom.start(RX2, TX2, %0000, 9_600)                            ' start serial for rn-42 (bluetooth)
                                                                  
  time.start                                                     ' for pause and timing
  time.pause(2000)                                               ' let everything get ready
                                                                  
                                                                  
                                                                  
dat { license }                                                   
                                                                  
{{                                                                

  Terms of Use: MIT License

  Permission is hereby granted, free of charge, to any person obtaining a copy of this
  software and associated documentation files (the "Software"), to deal in the Software
  without restriction, including without limitation the rights to use, copy, modify,
  merge, publish, distribute, sublicense, and/or sell copies of the Software, and to
  permit persons to whom the Software is furnished to do so, subject to the following
  conditions:

  The above copyright notice and this permission notice shall be included in all copies
  or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
  INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
  PARTICULAR PURPOSE AND NON-INFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
  HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
  CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE
  OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

}}